import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy } from '@angular/core';
import * as i1 from '@smallstack/rx-components';
import { IconComponent } from '@smallstack/theme-components';
import * as i5 from '@smallstack/type-components';
import { getSchemaPropertiesKeys } from '@smallstack/utils';
import { BaseWidgetComponent } from '@smallstack/widget-core';
import { BehaviorSubject, combineLatest, filter, switchMap, map } from 'rxjs';

class OfflineSearchWidgetComponent extends BaseWidgetComponent {
    #type;
    constructor(rxCollectionService, frontendTypeRegistry) {
        super();
        this.rxCollectionService = rxCollectionService;
        this.searchText$ = new BehaviorSubject(undefined);
        this.models$ = combineLatest([this.data$, this.searchText$]).pipe(filter(([data, searchText]) => data?.typePath !== undefined && searchText !== undefined), switchMap(async ([data, searchText]) => {
            const collection = await this.rxCollectionService.getCollection(data.typePath);
            return [data, searchText, collection];
        }), filter(([data, searchText, collection]) => collection !== undefined), switchMap(([data, searchText, collection]) => collection.rxCollection.find({
            sort: data.sort,
            selector: this.convertTextToQuery(searchText, collection.rxCollection.schema.jsonSchema)
        }).$), map((values) => values.map((value) => value.toJSON())));
        this.subscription.add(this.models$.subscribe((models) => this.sendSocketData("models", models)));
        this.subscription.add(this.data$.subscribe(async (data) => {
            if (data?.typePath !== undefined)
                this.#type = await frontendTypeRegistry.getTypeByPath(data.typePath);
        }));
    }
    convertTextToQuery(text, schema) {
        let parts = text?.match(/(?:[^\s"]+|"[^"]*")+/g);
        if (parts) {
            parts = parts.map((part) => part.replace(/"/g, ""));
            let allProperties = [];
            if (this.#type?.searchableFields instanceof Array && this.#type.searchableFields.length > 0)
                allProperties = this.#type.searchableFields?.map((field) => field.name);
            else
                allProperties = getSchemaPropertiesKeys(schema);
            const queryOrs = [];
            for (const part of parts) {
                for (const prop of allProperties) {
                    queryOrs.push({ [prop]: { $regex: new RegExp(part, "i") } });
                }
            }
            return { $or: queryOrs };
        }
        return {};
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.0.0", ngImport: i0, type: OfflineSearchWidgetComponent, deps: [{ token: i1.RxCollectionService }, { token: i5.FrontendTypeRegistry }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.0.0", type: OfflineSearchWidgetComponent, isStandalone: true, selector: "smallstack-offline-search-widget", usesInheritance: true, ngImport: i0, template: "<div class=\"form-control m-2\">\n  <div class=\"input-group\">\n    <input\n      #input\n      type=\"text\"\n      placeholder=\"Suchen...\"\n      class=\"input input-bordered w-full shadow-sm\"\n      (keyup)=\"searchText$.next($any($event.target).value)\"\n      (focus)=\"sendSocketData('focused')\"\n    />\n    <button class=\"btn btn-square btn-primary shadow-sm\" (click)=\"searchText$.next(input.value)\">\n      <smallstack-icon\n        name=\"search\"\n        theme=\"sf-regular\"\n        themeColor=\"daisyTheme.primary.textColor\"\n        size=\"md\"\n      ></smallstack-icon>\n    </button>\n  </div>\n</div>\n", dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "component", type: IconComponent, selector: "smallstack-icon", inputs: ["theme", "size", "name", "alias", "action", "actionSize", "spinning", "actionSpinning", "color", "themeColor", "actionColor", "badge", "badgeColor"], outputs: ["iconError"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.0.0", ngImport: i0, type: OfflineSearchWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: "smallstack-offline-search-widget", changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, imports: [CommonModule, IconComponent], template: "<div class=\"form-control m-2\">\n  <div class=\"input-group\">\n    <input\n      #input\n      type=\"text\"\n      placeholder=\"Suchen...\"\n      class=\"input input-bordered w-full shadow-sm\"\n      (keyup)=\"searchText$.next($any($event.target).value)\"\n      (focus)=\"sendSocketData('focused')\"\n    />\n    <button class=\"btn btn-square btn-primary shadow-sm\" (click)=\"searchText$.next(input.value)\">\n      <smallstack-icon\n        name=\"search\"\n        theme=\"sf-regular\"\n        themeColor=\"daisyTheme.primary.textColor\"\n        size=\"md\"\n      ></smallstack-icon>\n    </button>\n  </div>\n</div>\n" }]
        }], ctorParameters: function () { return [{ type: i1.RxCollectionService }, { type: i5.FrontendTypeRegistry }]; } });

export { OfflineSearchWidgetComponent };
//# sourceMappingURL=smallstack-data-widgets-offline-search-widget.component-0996fc50.mjs.map
